import { type UserConfig } from '@unocss/core';
import { type Theme } from '@unocss/preset-mini';
import { type FastifyInstance } from 'fastify';
import type pino from 'pino';
export type Mode = 'development' | 'production';
export type ValueOrCallback<T> = T | ((context: BuildContext) => T | Promise<T>);
export interface CSSClassGeneratorContext {
    prefix?: string;
    name: string;
    counter: number;
}
export interface BuildContext {
    version: string;
    logger: pino.Logger;
    isProduction: boolean;
    root: string;
    currentPage?: string;
    css: {
        keepExpanded: boolean;
        currentClasses: Set<string>;
        compressedClasses: Map<string, string>;
        compressionState: number;
    };
    extensions: any;
}
export interface BuildResult {
    cssConfig: ValueOrCallback<UserConfig<Theme>>;
    css?: ValueOrCallback<string>;
}
export type BuildFunction = (context: BuildContext) => BuildResult | Promise<BuildResult>;
export interface ServerResult {
    directory?: string;
}
export type ServerFunction = (server: FastifyInstance, isProduction?: boolean) => ServerResult | undefined | Promise<ServerResult | undefined>;
export declare const danteDir: string;
export declare const rootDir: string;
export declare const programName: string;
export declare const programDescription: string;
export declare const baseTemporaryDirectory: string;
export declare function resolveSwc(): Promise<string>;
export declare function buildFilePath(): string;
export declare function serverFilePath(): string;
export declare function createBuildContext(logger: pino.Logger, isProduction: boolean, root: string): BuildContext;
