import { glob } from 'glob';
import { resolve } from 'node:path';
import { fileURLToPath } from 'node:url';
export const danteDir = resolve(fileURLToPath(import.meta.url), '../..');
export const rootDir = process.cwd();
export const programName = process.env.DANTE_PROGRAM_NAME ?? 'dante';
export const programDescription = process.env.DANTE_PROGRAM_DESCRIPTION ?? 'Opinionated static site generator.';
export const baseTemporaryDirectory = process.env.DANTE_BASE_TEMPORARY_DIRECTORY ?? '.dante';
let swc;
export async function resolveSwc() {
    const location = await glob(resolve(rootDir, 'node_modules/**/@swc/cli/bin/swc.js'), {
        follow: true,
        dot: true
    });
    if (!location.length) {
        throw new Error('Cannot find swc.');
    }
    swc = location[0];
    return swc;
}
export function buildFilePath() {
    if (process.env.DANTE_BUILD_FILE_PATH) {
        return resolve(rootDir, process.env.DANTE_BUILD_FILE_PATH);
    }
    return resolve(rootDir, baseTemporaryDirectory, 'build/index.js');
}
export function serverFilePath() {
    if (process.env.DANTE_SERVER_FILE_PATH) {
        return resolve(rootDir, process.env.DANTE_SERVER_FILE_PATH);
    }
    return resolve(rootDir, baseTemporaryDirectory, 'build/server.js');
}
export function createBuildContext(logger, isProduction, root) {
    return {
        version: new Date().toISOString().replaceAll(/([:-])|(\.\d+Z$)/g, '').replace('T', '.'),
        logger,
        isProduction,
        root,
        css: {
            keepExpanded: !isProduction,
            currentClasses: new Set(),
            compressedClasses: new Map(),
            compressionState: 0
        },
        extensions: {}
    };
}
